==> mitol-django-authentication-1.4.0.tar.gz: mitol-django-authentication-1.4.0/mitol/authentication/CHANGELOG.md <==
# Changelog
All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [Unreleased]

## [1.4.0] - 2022-05-12

### Changed
- Bump `mitol-django-common` to `2.2.0`.

## [1.3.1] - 2021-11-16

## [1.3.0] - 2021-10-28

### Added
- Added custom `djoser` views and emails for password and email resets

## [1.2.0] - 2021-07-01

### Changed

- Support newer versions of `factory_boy`

### Added
- Support for Python 3.9

### Changed

- Allowed for a wider range of dependency versions

### Removed
- Support for Python 3.6

## [1.1.0] - 2021-04-07

### Changed
- Added usage of `SOCIAL_AUTH_SAML_IDP_ATTRIBUTE_NAME` to `SOCIAL_AUTH_SAML_ENABLED_IDPS`

## [1.0.0] - 2021-03-31

### Changed
- Bumped `mitol-django-mail` to `^1.0.0`

## [0.7.0] - 2021-03-30

### Changed
- Bumped `mitol-django-common` requirement to `~0.7.0`

## [0.6.0] - 2021-03-29

### Added
- Support django 3.x

## [0.5.0] - 2021-03-29
### Fixed
- App configuration import error fixed

## [0.4.0] - 2021-03-29
### Fixed
- Fix app configuration w/ namespace packages

## [0.3.0] - 2021-03-29

### Fixed
- Don't install test/dev dependencies

## [0.2.0] - 2021-03-29

### Added
- Barebones implementation of authentication app
- SAML metadata endpoint and boilerplate configuration

[Unreleased]: https://github.com/mitodl/ol-django/compare/mitol-django-authentication/v1.4.0...HEAD
[1.4.0]: https://github.com/mitodl/ol-django/compare/mitol-django-authentication/v1.3.1...mitol-django-authentication/v1.4.0
[1.3.1]: https://github.com/mitodl/ol-django/compare/mitol-django-authentication/v1.3.0...mitol-django-authentication/v1.3.1
[1.3.0]: https://github.com/mitodl/ol-django/compare/mitol-django-authentication/v1.2.0...mitol-django-authentication/v1.3.0
[1.2.0]: https://github.com/mitodl/ol-django/compare/mitol-django-authentication/v1.1.0...mitol-django-authentication/v1.2.0
[1.1.0]: https://github.com/mitodl/ol-django/compare/mitol-django-authentication/v0.2.0...mitol-django-authentication/v1.1.0
[1.0.0]: https://github.com/mitodl/ol-django/compare/mitol-django-authentication/v0.2.0...mitol-django-authentication/v1.0.0
[0.7.0]: https://github.com/mitodl/ol-django/compare/mitol-django-authentication/v0.2.0...mitol-django-authentication/v0.7.0
[0.6.0]: https://github.com/mitodl/ol-django/compare/mitol-django-authentication/v0.2.0...mitol-django-authentication/v0.6.0
[0.5.0]: https://github.com/mitodl/ol-django/compare/mitol-django-authentication/v0.2.0...mitol-django-authentication/v0.5.0
[0.4.0]: https://github.com/mitodl/ol-django/compare/mitol-django-authentication/v0.2.0...mitol-django-authentication/v0.4.0
[0.3.0]: https://github.com/mitodl/ol-django/compare/mitol-django-authentication/v0.2.0...mitol-django-authentication/v0.3.0
[0.2.0]: https://github.com/mitodl/ol-django/compare/ffca0142e4bfea14881047d3af168bd4aa32f6fa...mitol-django-authentication/v0.2.0

==> mitol-django-authentication-1.5.0.tar.gz: mitol-django-authentication-1.5.0/mitol/authentication/CHANGELOG.md <==
# Changelog
All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [Unreleased]

## [1.5.0] - 2022-06-24

## [1.4.1] - 2022-05-16

## [1.4.0] - 2022-05-12

### Changed
- Bump `mitol-django-common` to `2.2.0`.

## [1.3.1] - 2021-11-16

## [1.3.0] - 2021-10-28

### Added
- Added custom `djoser` views and emails for password and email resets

## [1.2.0] - 2021-07-01

### Changed

- Support newer versions of `factory_boy`

### Added
- Support for Python 3.9

### Changed

- Allowed for a wider range of dependency versions

### Removed
- Support for Python 3.6

## [1.1.0] - 2021-04-07

### Changed
- Added usage of `SOCIAL_AUTH_SAML_IDP_ATTRIBUTE_NAME` to `SOCIAL_AUTH_SAML_ENABLED_IDPS`

## [1.0.0] - 2021-03-31

### Changed
- Bumped `mitol-django-mail` to `^1.0.0`

## [0.7.0] - 2021-03-30

### Changed
- Bumped `mitol-django-common` requirement to `~0.7.0`

## [0.6.0] - 2021-03-29

### Added
- Support django 3.x

## [0.5.0] - 2021-03-29
### Fixed
- App configuration import error fixed

## [0.4.0] - 2021-03-29
### Fixed
- Fix app configuration w/ namespace packages

## [0.3.0] - 2021-03-29

### Fixed
- Don't install test/dev dependencies

## [0.2.0] - 2021-03-29

### Added
- Barebones implementation of authentication app
- SAML metadata endpoint and boilerplate configuration

[Unreleased]: https://github.com/mitodl/ol-django/compare/mitol-django-authentication/v1.5.0...HEAD
[1.5.0]: https://github.com/mitodl/ol-django/compare/mitol-django-authentication/v1.4.1...mitol-django-authentication/v1.5.0
[1.4.1]: https://github.com/mitodl/ol-django/compare/mitol-django-authentication/v1.4.0...mitol-django-authentication/v1.4.1
[1.4.0]: https://github.com/mitodl/ol-django/compare/mitol-django-authentication/v1.3.1...mitol-django-authentication/v1.4.0
[1.3.1]: https://github.com/mitodl/ol-django/compare/mitol-django-authentication/v1.3.0...mitol-django-authentication/v1.3.1
[1.3.0]: https://github.com/mitodl/ol-django/compare/mitol-django-authentication/v1.2.0...mitol-django-authentication/v1.3.0
[1.2.0]: https://github.com/mitodl/ol-django/compare/mitol-django-authentication/v1.1.0...mitol-django-authentication/v1.2.0
[1.1.0]: https://github.com/mitodl/ol-django/compare/mitol-django-authentication/v0.2.0...mitol-django-authentication/v1.1.0
[1.0.0]: https://github.com/mitodl/ol-django/compare/mitol-django-authentication/v0.2.0...mitol-django-authentication/v1.0.0
[0.7.0]: https://github.com/mitodl/ol-django/compare/mitol-django-authentication/v0.2.0...mitol-django-authentication/v0.7.0
[0.6.0]: https://github.com/mitodl/ol-django/compare/mitol-django-authentication/v0.2.0...mitol-django-authentication/v0.6.0
[0.5.0]: https://github.com/mitodl/ol-django/compare/mitol-django-authentication/v0.2.0...mitol-django-authentication/v0.5.0
[0.4.0]: https://github.com/mitodl/ol-django/compare/mitol-django-authentication/v0.2.0...mitol-django-authentication/v0.4.0
[0.3.0]: https://github.com/mitodl/ol-django/compare/mitol-django-authentication/v0.2.0...mitol-django-authentication/v0.3.0
[0.2.0]: https://github.com/mitodl/ol-django/compare/ffca0142e4bfea14881047d3af168bd4aa32f6fa...mitol-django-authentication/v0.2.0
